@@ -313,16 +313,17 @@ def main():
     workers_nums = opts.workers_nums
     with _reserve_port() as port:
         bind_address = f"[::]:{port}"
-        # Output information
-        print(f"1|1|tcp|127.0.0.1:{port}|grpc")
-        sys.stdout.flush()
+
         workers = []
-        log.info(f"starting workers: {workers_nums}")
+        #log.info(f"starting workers: {workers_nums}")
 
         for _ in range(workers_nums):
             worker = multiprocessing.Process(target=run_server, args=(bind_address,))
             worker.start()
             workers.append(worker)
+        # Output information
+        print(f"1|1|tcp|127.0.0.1:{port}|grpc")
+        sys.stdout.flush()
         for worker in workers:
             worker.join()
 
